# 超星学习通 deadline 汇总，目前仅适用于上海大学

## 使用方法

### 安装
python版本：3.7+
```bash
pip install ohmyddl --user
```
### 运行
- Windows
```
# 正常运行
ohmyddl.exe

# 输出调试信息
ohmyddl.exe -v

# 输出帮助信息
ohmyddl.exe -h
```

如果提示找不到命令可将上述 `ohmyddl.exe` 替换成 `python -m ohmyddl`。

- Linux
```
# 正常运行
ohmyddl

# 输出调试信息
ohmyddl -v

# 输出帮助信息
ohmyddl -h
```

如果提示找不到命令可将上述 `ohmyddl` 替换成 `python -m ohmyddl` 。

必要的时候使用 `pip3` 和 `python3` 而不是 `pip` ,  `python`。

## 反馈

- 邮箱： github@qiren.org
